==> nextcloud-27.1.2.tgz: nextcloud/apps/files_reminders/l10n/de_DE.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Set file reminders" : "Dateierinnerungen setzen",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Dateierinnerungen**\n\nSetze Dateierinnerungen.",
    "Back" : "Zurück",
    "Clear reminder" : "Erinnerung löschen",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für später heute erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für kommendes Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{filename}\" gesetzt",
    "Failed to set reminder" : "Fehler beim Setzen der Erinnerung",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Reminder cleared" : "Erinnerung gelöscht",
    "Failed to clear reminder" : "Fehler beim Löschen der Erinnerung",
    "Failed to load reminder" : "Fehler beim Laden der Erinnerung"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/files_reminders/l10n/de_DE.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Set file reminders" : "Dateierinnerungen setzen",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Dateierinnerungen**\n\nSetze Dateierinnerungen.",
    "We will remind you of this file" : "Sie werden an diese Datei erinnert werden",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Cancel" : "Abbrechen",
    "Set reminder" : "Erinnerung erstellen",
    "Set reminder for \"{fileName}\"" : "Erinnerung für \"{fileName}\" setzen",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Clear reminder" : "Erinnerung löschen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{filename}\" gesetzt",
    "Failed to set reminder" : "Fehler beim Setzen der Erinnerung",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für später heute erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für kommendes Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "Back" : "Zurück",
    "Reminder cleared" : "Erinnerung gelöscht",
    "Failed to clear reminder" : "Fehler beim Löschen der Erinnerung",
    "Failed to load reminder" : "Fehler beim Laden der Erinnerung"
},
"nplurals=2; plural=(n != 1);");
